@@ -1,20 +1,21 @@
 setupF <- function(fit, xvar, call.env, data) {
+  CALL <- if (isS4(fit)) fit@call else fit$call
   if (!is.null(data)) {
     Data <- data
-    CALL <- if (isS4(fit)) fit@call else fit$call
+  } else if (!is.null(CALL) && ('data' %in% names(CALL)) && exists(as.character(CALL$data), call.env)) {
+    env <- call.env
+    Data <- eval(CALL$data, envir=env)
   } else if (isS4(fit)) {
-    CALL <- fit@call
     FRAME <- try(fit@frame, silent=TRUE)
     DATA <- try(fit@data, silent=TRUE)
-    if (class(DATA) != 'try-error') {
+    if (!inherits(DATA, 'try-error')) {
       Data <- DATA
-    } else if (class(FRAME) != 'try-error') {
+    } else if (!inherits(FRAME, 'try-error')) {
       Data <- FRAME
     } else {
-      stop("visreg cannot find the data set used to fit your model; supply it using the 'data=' option")
+      stop("visreg cannot find the data set used to fit your model; supply it using the 'data=' option", call.=FALSE)
     }
   } else {
-    CALL <- fit$call
     ENV <- environment(fit$terms)
     if ("data" %in% names(fit) && is.data.frame(fit$data)) {
       Data <- fit$data
@@ -29,7 +30,7 @@ setupF <- function(fit, xvar, call.env, data) {
       env <- ENV
       Data <- eval(CALL$data, envir=ENV)
     } else {
-      stop("visreg cannot find the data set used to fit your model; supply it using the 'data=' option")
+      stop("visreg cannot find the data set used to fit your model; supply it using the 'data=' option", call.=FALSE)
     }
   }
   form <- formula(fit)
@@ -43,17 +44,17 @@ setupF <- function(fit, xvar, call.env, data) {
   }
   f <- as.data.frame(av)
 
-  if (class(CALL$random)=="call") {
+  if (inherits(CALL$random, "call")) {
     rf <- as.data.frame(as.list(get_all_vars(CALL$random, Data)))
-    rf <- rf[,setdiff(names(rf), names(f)),drop=FALSE]
+    rf <- rf[, setdiff(names(rf), names(f)), drop=FALSE]
     f <- cbind(f, rf)
   }
-  if ("subset" %in% names(CALL) & !('averaging' %in% class(fit))) {
+  if ("subset" %in% names(CALL) & !(inherits(fit, 'averaging'))) {
     s <- CALL$subset
     subset <- eval(substitute(s), Data, env)
-    f <- f[which(subset==TRUE),,drop=FALSE]
+    f <- f[which(subset==TRUE), , drop=FALSE]
   }
-  suppressWarnings(f <- f[!apply(is.na(f), 1, any),,drop=FALSE])
+  suppressWarnings(f <- f[!apply(is.na(f), 1, any), , drop=FALSE])
 
   # Handle some variable type issues
   needsUpdate <- FALSE
@@ -63,7 +64,7 @@ setupF <- function(fit, xvar, call.env, data) {
   if (any(frameClasses=="Surv")) needsUpdate <- TRUE
   if (any(frameClasses=="logical")) {
     needsUpdate <- TRUE
-    for (j in 1:ncol(f)) if (class(f[,j])[1]=="logical") f[,j] <- as.numeric(f[,j])
+    for (j in 1:ncol(f)) if (typeof(f[,j])=="logical") f[,j] <- as.double(f[,j])
   }
   if (missing(xvar)) {
     all_x <- strsplit(parseFormula(formula(fit)[3]), ' + ', fixed=TRUE)[[1]]
@@ -72,7 +73,7 @@ setupF <- function(fit, xvar, call.env, data) {
     xvar <- names(f)[!const & inModel]
   }
   if (length(xvar)==0) stop("The model has no predictors; visreg has nothing to plot.", call.=FALSE)
-  for (i in 1:length(xvar)){if (!is.element(xvar[i],names(f))) stop(paste(xvar[i], "not in model"))}
+  for (i in 1:length(xvar)){if (!is.element(xvar[i], names(f))) stop(paste(xvar[i], "not in model"), call.=FALSE)}
 
   attr(f, "needsUpdate") <- needsUpdate
   attr(f, "xvar") <- xvar
