@@ -1,21 +1,21 @@
 # setupV for visreg2d
 # Returns a list of x, y, and z for plotting
 setupV2 <- function(fit, f, xvar, yvar, nn, cond, type, scale, trans) {
-  n.z <- if (class(fit)[1]=="mlm") ncol(coef(fit)) else 1
+  n.z <- if (inherits(fit, "mlm")) ncol(coef(fit)) else 1
   form <- parseFormula(formula(fit)[3])
-  x <- f[,xvar]
-  y <- f[,yvar]
-  xx <- if(is.factor(x)) factor(levels(x),levels=levels(x)) else seq(min(x),max(x),length=nn)
-  yy <- if(is.factor(y)) factor(levels(y),levels=levels(y)) else seq(min(y),max(y),length=nn)
-  xydf <- as.data.frame(expand.grid(xx,yy))
-  names(xydf) <- c(xvar,yvar)
+  x <- f[, xvar]
+  y <- f[, yvar]
+  xx <- if(is.factor(x)) factor(levels(x), levels=levels(x)) else seq(min(x), max(x), length=nn)
+  yy <- if(is.factor(y)) factor(levels(y), levels=levels(y)) else seq(min(y), max(y), length=nn)
+  xydf <- as.data.frame(expand.grid(xx, yy))
+  names(xydf) <- c(xvar, yvar)
 
   if (type=="conditional") {
     df <- fillFrame(f, xydf, cond)
-    DD <- model.frame(as.formula(paste("~",form)),df)
-    DD <- cbind(DD,df[,setdiff(names(df),names(DD)),drop=FALSE])
+    DD <- model.frame(as.formula(paste("~", form)), df)
+    DD <- cbind(DD, df[, setdiff(names(df), names(DD)), drop=FALSE])
     P <- predict(fit, newdata=DD)
-    if (class(fit)[1]=="mlm") {
+    if (inherits(fit, "mlm")) {
       z <- vector("list", n.z)
       for (i in 1:n.z) z[[i]] <- matrix(trans(P[,i]), nrow=length(xx), ncol=length(yy))
     } else {
@@ -27,25 +27,24 @@ setupV2 <- function(fit, f, xvar, yvar, nn, cond, type, scale, trans) {
     xydf <- rbind(c(xref, yref), xydf)
     df <- fillFrame(f, xydf, cond)
     DD <- rbind(f, df)
-    if (class(fit)[1]=="mlm") {
+    if (inherits(fit, "mlm")) {
       ind <- apply(is.finite(coef(fit)), 1, all)
-      if (!identical(ind, apply(is.finite(coef(fit)), 1, any))) stop("Inconsistent NA/NaN coefficients across outcomes")
+      if (!identical(ind, apply(is.finite(coef(fit)), 1, any))) stop("Inconsistent NA/NaN coefficients across outcomes", call.=FALSE)
     } else ind <- is.finite(coef(fit))
-    XX. <- model.matrix(as.formula(paste("~",formula(fit)[3])),DD)[-(1:nrow(f)), ind]
+    XX. <- model.matrix(as.formula(paste("~", formula(fit)[3])), DD)[-(1:nrow(f)), ind]
     XX <- t(t(XX.[-1,])-XX.[1,])
-    if (class(fit)[1]=="mlm") {
+    if (inherits(fit, "mlm")) {
       z <- vector("list", n.z)
-      for (i in 1:n.z) z[[i]] <- matrix(trans(XX%*%coef(fit)[ind,i]), nrow=length(xx), ncol=length(yy))
+      for (i in 1:n.z) z[[i]] <- matrix(trans(XX%*%coef(fit)[ind, i]), nrow=length(xx), ncol=length(yy))
     } else {
-      z <- matrix(trans(XX%*%coef(fit)[ind]),nrow=length(xx),ncol=length(yy))
+      z <- matrix(trans(XX%*%coef(fit)[ind]), nrow=length(xx), ncol=length(yy))
     }
   }
-  #zname <- if (class(fit)[1]=="mlm") colnames(fit$fitted.values) else as.character(formula(fit)[2])
   zname <- makeYName(fit, scale, trans, type)
-  D <- model.frame(as.formula(paste("~",form)),df)
+  D <- model.frame(as.formula(paste("~", form)), df)
   condNames <- setdiff(names(D), c(xvar, yvar))
   condNames <- intersect(condNames, names(df))
-  baseMeta <- list(x=xvar, y=yvar, trans=trans, class=class(fit), cond=D[1,condNames,drop=FALSE])
+  baseMeta <- list(x=xvar, y=yvar, trans=trans, class=class(fit), cond=D[1, condNames, drop=FALSE])
 
   if (n.z > 1) {
     v <- vector("list", n.z)
