@@ -22,3 +22,11 @@ plot(v, overlay=TRUE, strip.names=LETTERS[1:10])
 
 visreg(fit, "x", type="contrast")
 visreg(fit, "x", by="ID", type="contrast")
+
+# Works with a cbind() formula
+y1 <- sample(101:200, n*j, replace=TRUE)
+y2 <- sample(0:100, n*j, replace=TRUE)
+df <- data.frame(y1=y1, y2=y2, x=x, ID=factor(ID))
+
+fit <- glmer(cbind(y1, y2) ~ x + (1|ID), data=df, family='binomial')
+visreg(fit, "x")
